Documentation
¶
Overview ¶
Package ms is a library for mass spectrometry data
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Scan ¶
type Scan struct {
Analyzer Analyzer
MSLevel uint8
//Spectrum is a function forcing the read of a spectrum,
//which is "delayed" for efficiency reasons. If it was not delayed
//and Spectrum were a data structure, it would always have to
//be read, which is very expensive. Now if only another property of
//Scan (cheaper to obtain) is requested, resources are saved.
Spectrum func(centroided ...bool) Spectrum
//PrecursorMzs is only filled with mz values at MSx scans.
PrecursorMzs []float64
Time float64
}
Scan represents the peak acquisition event of the mass spectrometer
Directories
¶
| Path | Synopsis |
|---|---|
|
Package unthermo is a library that can read Thermo RAW files.
|
Package unthermo is a library that can read Thermo RAW files. |
|
tools
command
A set of tools using the unthermo library The labelq tool inserts iTRAQ reporter ions from HCD scans in CID spectra.
|
A set of tools using the unthermo library The labelq tool inserts iTRAQ reporter ions from HCD scans in CID spectra. |
Click to show internal directories.
Click to hide internal directories.